Class: Google::Apis::AddressvalidationV1::GoogleMapsAddressvalidationV1Address
- Inherits:
-
Object
- Object
- Google::Apis::AddressvalidationV1::GoogleMapsAddressvalidationV1Address
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/addressvalidation_v1/classes.rb,
lib/google/apis/addressvalidation_v1/representations.rb,
lib/google/apis/addressvalidation_v1/representations.rb
Overview
Details of the post-processed address. Post-processing includes correcting misspelled parts of the address, replacing incorrect parts, and inferring missing parts.
Instance Attribute Summary collapse
-
#address_components ⇒ Array<Google::Apis::AddressvalidationV1::GoogleMapsAddressvalidationV1AddressComponent>
Unordered list.
-
#formatted_address ⇒ String
The post-processed address, formatted as a single-line address following the address formatting rules of the region where the address is located.
-
#missing_component_types ⇒ Array<String>
The types of components that were expected to be present in a correctly formatted mailing address but were not found in the input AND could not be inferred.
-
#postal_address ⇒ Google::Apis::AddressvalidationV1::GoogleTypePostalAddress
Represents a postal address, such as for postal delivery or payments addresses.
-
#unconfirmed_component_types ⇒ Array<String>
The types of the components that are present in the
address_componentsbut could not be confirmed to be correct. -
#unresolved_tokens ⇒ Array<String>
Any tokens in the input that could not be resolved.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsAddressvalidationV1Address
constructor
A new instance of GoogleMapsAddressvalidationV1Address.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsAddressvalidationV1Address
Returns a new instance of GoogleMapsAddressvalidationV1Address.
146 147 148 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 146 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address_components ⇒ Array<Google::Apis::AddressvalidationV1::GoogleMapsAddressvalidationV1AddressComponent>
Unordered list. The individual address components of the formatted and
corrected address, along with validation information. This provides
information on the validation status of the individual components. Address
components are not ordered in a particular way. Do not make any assumptions on
the ordering of the address components in the list.
Corresponds to the JSON property addressComponents
84 85 86 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 84 def address_components @address_components end |
#formatted_address ⇒ String
The post-processed address, formatted as a single-line address following the
address formatting rules of the region where the address is located. Note: the
format of this address may not match the format of the address in the
postal_address field. For example, the postal_address always represents the
country as a 2 letter region_code, such as "US" or "NZ". By contrast, this
field uses a longer form of the country name, such as "USA" or "New Zealand".
Corresponds to the JSON property formattedAddress
94 95 96 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 94 def formatted_address @formatted_address end |
#missing_component_types ⇒ Array<String>
The types of components that were expected to be present in a correctly
formatted mailing address but were not found in the input AND could not be
inferred. An example might be ['street_number', 'route'] for an input like "
Boulder, Colorado, 80301, USA". The list of possible types can be found here. Note: you might see a missing component type when you think you've
already supplied the missing component. For example, this can happen when
the input address contains the building name, but not the premise number. In
the address "渋谷区渋谷3丁目 Shibuya Stream", the building name "Shibuya Stream" has
the component type premise, but the premise number is missing, so
missing_component_types will contain premise.
Corresponds to the JSON property missingComponentTypes
109 110 111 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 109 def missing_component_types @missing_component_types end |
#postal_address ⇒ Google::Apis::AddressvalidationV1::GoogleTypePostalAddress
Represents a postal address, such as for postal delivery or payments addresses.
With a postal address, a postal service can deliver items to a premise, P.O.
box, or similar. A postal address is not intended to model geographical
locations like roads, towns, or mountains. In typical usage, an address would
be created by user input or from importing existing data, depending on the
type of process. Advice on address input or editing: - Use an
internationalization-ready address widget such as https://github.com/google/
libaddressinput. - Users should not be presented with UI elements for input or
editing of fields outside countries where that field is used. For more
guidance on how to use this schema, see: https://support.google.com/business/
answer/6397478.
Corresponds to the JSON property postalAddress
124 125 126 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 124 def postal_address @postal_address end |
#unconfirmed_component_types ⇒ Array<String>
The types of the components that are present in the address_components but
could not be confirmed to be correct. This field is provided for the sake of
convenience: its contents are equivalent to iterating through the
address_components to find the types of all the components where the
confirmation_level is not CONFIRMED or the inferred flag is not set to true.
The list of possible types can be found here.
Corresponds to the JSON property unconfirmedComponentTypes
135 136 137 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 135 def unconfirmed_component_types @unconfirmed_component_types end |
#unresolved_tokens ⇒ Array<String>
Any tokens in the input that could not be resolved. This might be an input
that was not recognized as a valid part of an address. For example, for an
input such as "Parcel 0000123123 & 0000456456 Str # Guthrie Center IA 50115 US"
, the unresolved tokens might look like ["Parcel", "0000123123", "&", "
0000456456"].
Corresponds to the JSON property unresolvedTokens
144 145 146 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 144 def unresolved_tokens @unresolved_tokens end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
151 152 153 154 155 156 157 158 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 151 def update!(**args) @address_components = args[:address_components] if args.key?(:address_components) @formatted_address = args[:formatted_address] if args.key?(:formatted_address) @missing_component_types = args[:missing_component_types] if args.key?(:missing_component_types) @postal_address = args[:postal_address] if args.key?(:postal_address) @unconfirmed_component_types = args[:unconfirmed_component_types] if args.key?(:unconfirmed_component_types) @unresolved_tokens = args[:unresolved_tokens] if args.key?(:unresolved_tokens) end |