Class: Google::Apis::AddressvalidationV1::GoogleMapsAddressvalidationV1AddressMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/addressvalidation_v1/classes.rb,
lib/google/apis/addressvalidation_v1/representations.rb,
lib/google/apis/addressvalidation_v1/representations.rb

Overview

The metadata for the post-processed address. metadata is not guaranteed to be fully populated for every address sent to the Address Validation API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsAddressvalidationV1AddressMetadata

Returns a new instance of GoogleMapsAddressvalidationV1AddressMetadata.



257
258
259
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 257

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#businessBoolean Also known as: business?

Indicates that this is the address of a business. If unset, indicates that the value is unknown. Corresponds to the JSON property business

Returns:

  • (Boolean)


240
241
242
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 240

def business
  @business
end

#po_boxBoolean Also known as: po_box?

Indicates that the address of a PO box. If unset, indicates that the value is unknown. Corresponds to the JSON property poBox

Returns:

  • (Boolean)


247
248
249
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 247

def po_box
  @po_box
end

#residentialBoolean Also known as: residential?

Indicates that this is the address of a residence. If unset, indicates that the value is unknown. Corresponds to the JSON property residential

Returns:

  • (Boolean)


254
255
256
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 254

def residential
  @residential
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



262
263
264
265
266
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 262

def update!(**args)
  @business = args[:business] if args.key?(:business)
  @po_box = args[:po_box] if args.key?(:po_box)
  @residential = args[:residential] if args.key?(:residential)
end