Class: Google::Apis::AddressvalidationV1::GoogleMapsAddressvalidationV1LanguageOptions
- Inherits:
-
Object
- Object
- Google::Apis::AddressvalidationV1::GoogleMapsAddressvalidationV1LanguageOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/addressvalidation_v1/classes.rb,
lib/google/apis/addressvalidation_v1/representations.rb,
lib/google/apis/addressvalidation_v1/representations.rb
Overview
Preview: This feature is in Preview (pre-GA). Pre-GA products and features might have limited support, and changes to pre-GA products and features might not be compatible with other pre-GA versions. Pre-GA Offerings are covered by the Google Maps Platform Service Specific Terms. For more information, see the launch stage descriptions. Enables the Address Validation API to include additional information in the response.
Instance Attribute Summary collapse
-
#return_english_latin_address ⇒ Boolean
(also: #return_english_latin_address?)
Preview: Return a [google.maps.addressvalidation.v1.Address] in English.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsAddressvalidationV1LanguageOptions
constructor
A new instance of GoogleMapsAddressvalidationV1LanguageOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsAddressvalidationV1LanguageOptions
Returns a new instance of GoogleMapsAddressvalidationV1LanguageOptions.
389 390 391 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#return_english_latin_address ⇒ Boolean Also known as: return_english_latin_address?
Preview: Return a [google.maps.addressvalidation.v1.Address] in English. See [
google.maps.addressvalidation.v1.ValidationResult.english_latin_address] for
details.
Corresponds to the JSON property returnEnglishLatinAddress
386 387 388 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 386 def return_english_latin_address @return_english_latin_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
394 395 396 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 394 def update!(**args) @return_english_latin_address = args[:return_english_latin_address] if args.key?(:return_english_latin_address) end |