Class: Google::Apis::AddressvalidationV1::GoogleMapsAddressvalidationV1ValidationResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/addressvalidation_v1/classes.rb,
lib/google/apis/addressvalidation_v1/representations.rb,
lib/google/apis/addressvalidation_v1/representations.rb

Overview

The result of validating an address.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleMapsAddressvalidationV1ValidationResult

Returns a new instance of GoogleMapsAddressvalidationV1ValidationResult.



1017
1018
1019
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 1017

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressGoogle::Apis::AddressvalidationV1::GoogleMapsAddressvalidationV1Address

Details of the post-processed address. Post-processing includes correcting misspelled parts of the address, replacing incorrect parts, and inferring missing parts. Corresponds to the JSON property address



984
985
986
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 984

def address
  @address
end

#english_latin_addressGoogle::Apis::AddressvalidationV1::GoogleMapsAddressvalidationV1Address

Details of the post-processed address. Post-processing includes correcting misspelled parts of the address, replacing incorrect parts, and inferring missing parts. Corresponds to the JSON property englishLatinAddress



991
992
993
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 991

def english_latin_address
  @english_latin_address
end

#geocodeGoogle::Apis::AddressvalidationV1::GoogleMapsAddressvalidationV1Geocode

Contains information about the place the input was geocoded to. Corresponds to the JSON property geocode



996
997
998
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 996

def geocode
  @geocode
end

#metadataGoogle::Apis::AddressvalidationV1::GoogleMapsAddressvalidationV1AddressMetadata

The metadata for the post-processed address. metadata is not guaranteed to be fully populated for every address sent to the Address Validation API. Corresponds to the JSON property metadata



1002
1003
1004
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 1002

def 
  @metadata
end

#usps_dataGoogle::Apis::AddressvalidationV1::GoogleMapsAddressvalidationV1UspsData

The USPS data for the address. uspsData is not guaranteed to be fully populated for every US or PR address sent to the Address Validation API. It's recommended to integrate the backup address fields in the response if you utilize uspsData as the primary part of the response. Corresponds to the JSON property uspsData



1010
1011
1012
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 1010

def usps_data
  @usps_data
end

#verdictGoogle::Apis::AddressvalidationV1::GoogleMapsAddressvalidationV1Verdict

High level overview of the address validation result and geocode. Corresponds to the JSON property verdict



1015
1016
1017
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 1015

def verdict
  @verdict
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1022
1023
1024
1025
1026
1027
1028
1029
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 1022

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @english_latin_address = args[:english_latin_address] if args.key?(:english_latin_address)
  @geocode = args[:geocode] if args.key?(:geocode)
  @metadata = args[:metadata] if args.key?(:metadata)
  @usps_data = args[:usps_data] if args.key?(:usps_data)
  @verdict = args[:verdict] if args.key?(:verdict)
end