Class: Google::Apis::AddressvalidationV1::GoogleMapsAddressvalidationV1Verdict
- Inherits:
-
Object
- Object
- Google::Apis::AddressvalidationV1::GoogleMapsAddressvalidationV1Verdict
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/addressvalidation_v1/classes.rb,
lib/google/apis/addressvalidation_v1/representations.rb,
lib/google/apis/addressvalidation_v1/representations.rb
Overview
High level overview of the address validation result and geocode.
Instance Attribute Summary collapse
-
#address_complete ⇒ Boolean
(also: #address_complete?)
The post-processed address is considered complete if there are no unresolved tokens, no unexpected or missing address components.
-
#geocode_granularity ⇒ String
Information about the granularity of the
geocode. -
#has_inferred_components ⇒ Boolean
(also: #has_inferred_components?)
At least one address component was inferred (added) that wasn't in the input, see [google.maps.addressvalidation.v1.Address.address_components] for details.
-
#has_replaced_components ⇒ Boolean
(also: #has_replaced_components?)
At least one address component was replaced, see [google.maps. addressvalidation.v1.Address.address_components] for details.
-
#has_spell_corrected_components ⇒ Boolean
(also: #has_spell_corrected_components?)
At least one address component was spell-corrected, see [google.maps. addressvalidation.v1.Address.address_components] for details.
-
#has_unconfirmed_components ⇒ Boolean
(also: #has_unconfirmed_components?)
At least one address component cannot be categorized or validated, see [google. maps.addressvalidation.v1.Address.address_components] for details.
-
#input_granularity ⇒ String
The granularity of the input address.
-
#possible_next_action ⇒ String
Preview: This feature is in Preview (pre-GA).
-
#validation_granularity ⇒ String
The level of granularity for the post-processed address that the API can fully validate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleMapsAddressvalidationV1Verdict
constructor
A new instance of GoogleMapsAddressvalidationV1Verdict.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleMapsAddressvalidationV1Verdict
Returns a new instance of GoogleMapsAddressvalidationV1Verdict.
1120 1121 1122 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 1120 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address_complete ⇒ Boolean Also known as: address_complete?
The post-processed address is considered complete if there are no unresolved
tokens, no unexpected or missing address components. If unset, indicates that
the value is false. See missing_component_types, unresolved_tokens or
unexpected fields for more details.
Corresponds to the JSON property addressComplete
1042 1043 1044 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 1042 def address_complete @address_complete end |
#geocode_granularity ⇒ String
Information about the granularity of the geocode. This can be understood as
the semantic meaning of how coarse or fine the geocoded location is. This can
differ from the validation_granularity above occasionally. For example, our
database might record the existence of an apartment number but do not have a
precise location for the apartment within a big apartment complex. In that
case, the validation_granularity will be SUB_PREMISE but the
geocode_granularity will be PREMISE.
Corresponds to the JSON property geocodeGranularity
1054 1055 1056 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 1054 def geocode_granularity @geocode_granularity end |
#has_inferred_components ⇒ Boolean Also known as: has_inferred_components?
At least one address component was inferred (added) that wasn't in the input,
see [google.maps.addressvalidation.v1.Address.address_components] for details.
Corresponds to the JSON property hasInferredComponents
1060 1061 1062 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 1060 def has_inferred_components @has_inferred_components end |
#has_replaced_components ⇒ Boolean Also known as: has_replaced_components?
At least one address component was replaced, see [google.maps.
addressvalidation.v1.Address.address_components] for details.
Corresponds to the JSON property hasReplacedComponents
1067 1068 1069 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 1067 def has_replaced_components @has_replaced_components end |
#has_spell_corrected_components ⇒ Boolean Also known as: has_spell_corrected_components?
At least one address component was spell-corrected, see [google.maps.
addressvalidation.v1.Address.address_components] for details.
Corresponds to the JSON property hasSpellCorrectedComponents
1074 1075 1076 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 1074 def has_spell_corrected_components @has_spell_corrected_components end |
#has_unconfirmed_components ⇒ Boolean Also known as: has_unconfirmed_components?
At least one address component cannot be categorized or validated, see [google.
maps.addressvalidation.v1.Address.address_components] for details.
Corresponds to the JSON property hasUnconfirmedComponents
1081 1082 1083 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 1081 def has_unconfirmed_components @has_unconfirmed_components end |
#input_granularity ⇒ String
The granularity of the input address. This is the result of parsing the
input address and does not give any validation signals. For validation signals,
refer to validation_granularity below. For example, if the input address
includes a specific apartment number, then the input_granularity here will
be SUB_PREMISE. If the address validation service cannot match the apartment
number in the databases or the apartment number is invalid, the
validation_granularity will likely be PREMISE or more coarse.
Corresponds to the JSON property inputGranularity
1093 1094 1095 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 1093 def input_granularity @input_granularity end |
#possible_next_action ⇒ String
Preview: This feature is in Preview (pre-GA). Pre-GA products and features
might have limited support, and changes to pre-GA products and features might
not be compatible with other pre-GA versions. Pre-GA Offerings are covered by
the Google Maps Platform Service Specific Terms. For more information, see the launch
stage descriptions. Offers
an interpretive summary of the API response, intended to assist in determining
a potential subsequent action to take. This field is derived from other fields
in the API response and should not be considered as a guarantee of address
accuracy or deliverability. See Build your validation logic for more details.
Corresponds to the JSON property possibleNextAction
1109 1110 1111 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 1109 def possible_next_action @possible_next_action end |
#validation_granularity ⇒ String
The level of granularity for the post-processed address that the API can fully
validate. For example, a validation_granularity of PREMISE indicates all
address components at the level of PREMISE or more coarse can be validated.
Per address component validation result can be found in [google.maps.
addressvalidation.v1.Address.address_components].
Corresponds to the JSON property validationGranularity
1118 1119 1120 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 1118 def validation_granularity @validation_granularity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 |
# File 'lib/google/apis/addressvalidation_v1/classes.rb', line 1125 def update!(**args) @address_complete = args[:address_complete] if args.key?(:address_complete) @geocode_granularity = args[:geocode_granularity] if args.key?(:geocode_granularity) @has_inferred_components = args[:has_inferred_components] if args.key?(:has_inferred_components) @has_replaced_components = args[:has_replaced_components] if args.key?(:has_replaced_components) @has_spell_corrected_components = args[:has_spell_corrected_components] if args.key?(:has_spell_corrected_components) @has_unconfirmed_components = args[:has_unconfirmed_components] if args.key?(:has_unconfirmed_components) @input_granularity = args[:input_granularity] if args.key?(:input_granularity) @possible_next_action = args[:possible_next_action] if args.key?(:possible_next_action) @validation_granularity = args[:validation_granularity] if args.key?(:validation_granularity) end |